==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/dlm/kotlin/inputs/LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.dlm.kotlin.inputs

import com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cmkArn The Amazon Resource Name (ARN) of the AWS KMS customer master key (CMK) to use for EBS encryption. If this argument is not specified, the default KMS key for the account is used.
 * @property encrypted To encrypt a copy of an unencrypted snapshot if encryption by default is not enabled, enable encryption using this parameter. Copies of encrypted snapshots are encrypted, even if this parameter is false or if encryption by default is not enabled.
 */
public data class LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs(
    public val cmkArn: Output<String>? = null,
    public val encrypted: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs> {
    override fun toJava():
        com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs =
        com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs.builder()
            .cmkArn(cmkArn?.applyValue({ args0 -> args0 }))
            .encrypted(encrypted?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs].
 */
@PulumiTagMarker
public class LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgsBuilder
internal constructor() {
    private var cmkArn: Output<String>? = null

    private var encrypted: Output<Boolean>? = null

    /**
     * @param value The Amazon Resource Name (ARN) of the AWS KMS customer master key (CMK) to use for EBS encryption. If this argument is not specified, the default KMS key for the account is used.
     */
    @JvmName("qjylllgkdjenddkg")
    public suspend fun cmkArn(`value`: Output<String>) {
        this.cmkArn = value
    }

    /**
     * @param value To encrypt a copy of an unencrypted snapshot if encryption by default is not enabled, enable encryption using this parameter. Copies of encrypted snapshots are encrypted, even if this parameter is false or if encryption by default is not enabled.
     */
    @JvmName("fhxxtictpmyftsib")
    public suspend fun encrypted(`value`: Output<Boolean>) {
        this.encrypted = value
    }

    /**
     * @param value The Amazon Resource Name (ARN) of the AWS KMS customer master key (CMK) to use for EBS encryption. If this argument is not specified, the default KMS key for the account is used.
     */
    @JvmName("olngpuuhhookxprb")
    public suspend fun cmkArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cmkArn = mapped
    }

    /**
     * @param value To encrypt a copy of an unencrypted snapshot if encryption by default is not enabled, enable encryption using this parameter. Copies of encrypted snapshots are encrypted, even if this parameter is false or if encryption by default is not enabled.
     */
    @JvmName("vufkhcxapfykymqr")
    public suspend fun encrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encrypted = mapped
    }

    internal fun build(): LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs =
        LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs(
            cmkArn = cmkArn,
            encrypted = encrypted,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/dlm/kotlin/inputs/LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.dlm.kotlin.inputs

import com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cmkArn
 * @property encrypted
 */
public data class LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs(
    public val cmkArn: Output<String>? = null,
    public val encrypted: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs =
        com.pulumi.aws.dlm.inputs.LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs.builder()
            .cmkArn(cmkArn?.applyValue({ args0 -> args0 }))
            .encrypted(encrypted?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs].
 */
@PulumiTagMarker
public class LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgsBuilder
internal constructor() {
    private var cmkArn: Output<String>? = null

    private var encrypted: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("gqovgbbgwicxcypr")
    public suspend fun cmkArn(`value`: Output<String>) {
        this.cmkArn = value
    }

    /**
     * @param value
     */
    @JvmName("ngeskgqrwrmeyvyi")
    public suspend fun encrypted(`value`: Output<Boolean>) {
        this.encrypted = value
    }

    /**
     * @param value
     */
    @JvmName("plreacqnwudoooeu")
    public suspend fun cmkArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cmkArn = mapped
    }

    /**
     * @param value
     */
    @JvmName("naxaylwxbhvshipo")
    public suspend fun encrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encrypted = mapped
    }

    internal fun build(): LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs = LifecyclePolicyPolicyDetailsActionCrossRegionCopyEncryptionConfigurationArgs(
        cmkArn = cmkArn,
        encrypted = encrypted,
    )
}
